@@ -612,7 +612,6 @@ class AutoInceptionFedAvg(AutoInception, AutoFedAvgModel):
                              max_rounds=self.config.epochs,
                              log_rounds=1)
 
-    @property
     def fine_tuned_files_dict(self) -> Optional[Dict[str, str]]:
         param_file = os.path.join(self.result_dir, self.config.param_file)
         with open(param_file, 'wb') as f:
@@ -630,8 +629,6 @@ class InceptionFedAvgScheduler(AutoFedAvgScheduler):
 
     def __init__(self,
                  auto_proxy: AutoInceptionFedAvg,
-                 min_clients: int,
-                 max_clients: int,
                  max_rounds: int = 0,
                  merge_epochs: int = 1,
                  calculation_timeout: int = 300,
@@ -639,8 +636,6 @@ class InceptionFedAvgScheduler(AutoFedAvgScheduler):
                  log_rounds: int = 0,
                  involve_aggregator: bool = False):
         super().__init__(auto_proxy=auto_proxy,
-                         min_clients=min_clients,
-                         max_clients=max_clients,
                          max_rounds=max_rounds,
                          merge_epochs=merge_epochs,
                          calculation_timeout=calculation_timeout,
@@ -667,7 +662,7 @@ class InceptionFedAvgScheduler(AutoFedAvgScheduler):
     def train_an_epoch(self):
         self.auto_proxy.train_an_epoch()
 
-    def test(self):
+    def run_test(self):
         avg_loss, correct_rate = self.auto_proxy.run_test()
 
         self.tb_writer.add_scalar('test_results/avg_loss', avg_loss, self.current_round)
