@@ -3,13 +3,13 @@
 from dataclasses import dataclass
 from typing import Dict
 
-from ...contractor import (ApplySendingDataEvent, ContractEvent,
+from ...contractor import (ApplySharedFileSendingDataEvent, ContractEvent,
                            TaskMessageContractor, TaskMessageEventFactory)
 
 
 @dataclass
 class PSIInitEvent(ContractEvent):
-    """A event to initiate a RSA based PSI session."""
+    """An event to initiate a RSA based PSI session."""
 
     TYPE = 'rsa_psi_init'
 
@@ -26,7 +26,7 @@ class PSIInitEvent(ContractEvent):
 
 @dataclass
 class PublicKeyEvent(ContractEvent):
-    """A event to send the public key."""
+    """An event to send the public key."""
 
     TYPE = 'public_key'
 
@@ -34,6 +34,12 @@ class PublicKeyEvent(ContractEvent):
     n: int
     e: int
 
+    def event_to_contract(self) -> dict:
+        event_dict = super().event_to_contract()
+        # n is a so big integer that it could be transfered to the format like 1.2e345
+        event_dict['n'] = str(self.n)
+        return event_dict
+
     @classmethod
     def contract_to_event(cls, contract: dict) -> 'PublicKeyEvent':
         event_type = contract.get('type')
@@ -44,14 +50,16 @@ class PublicKeyEvent(ContractEvent):
         assert (
             collaborator and isinstance(collaborator, str)
         ), f'invalid collaborator: {collaborator}'
-        assert n and isinstance(n, int) and n > 0, f'invalid public key: {n=}'
+        assert n and isinstance(n, str) and n.isdecimal(), f'invalid public key: {n=}'
+        n = int(n)
+        assert n > 0, f'invalid public key: {n=}'
         assert e and isinstance(e, int) and n > 0, f'invalid public key: {e=}'
         return PublicKeyEvent(collaborator=collaborator, n=n, e=e)
 
 
 @dataclass
 class ReadyForSignedIdsEvent(ContractEvent):
-    """A event to send the public key."""
+    """An event to send the public key."""
 
     TYPE = 'ready_for_signed_ids'
 
@@ -66,12 +74,6 @@ class ReadyForSignedIdsEvent(ContractEvent):
         return ReadyForSignedIdsEvent(initiator=initiator)
 
 
-# define some more friendly alias
-SendingBlindIdsEvent = ApplySendingDataEvent
-SendingSignedIdsEvent = ApplySendingDataEvent
-DistributingIntersectionEvent = ApplySendingDataEvent
-
-
 class RSAEventFactory(TaskMessageEventFactory):
 
     _CLASS_MAP: Dict[str, ContractEvent] = {
