@@ -4,8 +4,7 @@ import secrets
 from dataclasses import dataclass
 from typing import List
 
-from ..contractor import (ApplySendingDataEvent, ContractEvent,
-                          TaskMessageContractor)
+from ..contractor import ContractEvent, TaskMessageContractor
 from .psi.rsa_psi_contractor import RSAContractor, RSAEventFactory
 
 
@@ -275,14 +274,17 @@ class CompleteTaskEvent(ContractEvent):
         return CompleteTaskEvent()
 
 
-# define some more friendly alias
-SendFeatureEvent = ApplySendingDataEvent
-SendCipherPorjectionEvent = ApplySendingDataEvent
-SendNoisedPorjectionEvent = ApplySendingDataEvent
-SendCipherWGradEvent = ApplySendingDataEvent
-SendNoisedWGradEvent = ApplySendingDataEvent
-SendCipherFeatureGradEvent = ApplySendingDataEvent
-SendTestFeatureEvent = ApplySendingDataEvent
+@dataclass
+class ResetRoundEvent(ContractEvent):
+    """An event of resetting context of current training round."""
+
+    TYPE = 'reset_round'
+
+    @classmethod
+    def contract_to_event(cls, contract: dict) -> 'ResetRoundEvent':
+        event_type = contract.get('type')
+        assert event_type == cls.TYPE, f'合约类型错误: {event_type}'
+        return ResetRoundEvent()
 
 
 class HeteroNNEventFactory(RSAEventFactory):
@@ -302,6 +304,7 @@ class HeteroNNEventFactory(RSAEventFactory):
         CollaboratorCompleteEvent.TYPE: CollaboratorCompleteEvent,
         FailTaskEvent.TYPE: FailTaskEvent,
         CompleteTaskEvent.TYPE: CompleteTaskEvent,
+        ResetRoundEvent.TYPE: ResetRoundEvent,
         **RSAEventFactory._CLASS_MAP,
     }
 
@@ -327,11 +330,11 @@ class HeteroNNContractor(RSAContractor):
         self._new_contract(targets=self.EVERYONE, event=event)
         return nonce
 
-    def respond_checkin(self,
-                        round: int,
-                        host: str,
-                        nonce: str,
-                        requester_id: str):
+    def respond_check_in(self,
+                         round: int,
+                         host: str,
+                         nonce: str,
+                         requester_id: str):
         """Respond checkin event."""
         event = CheckinResponseEvent(round=round, host=host, nonce=nonce)
         self._new_contract(targets=[requester_id], event=event)
@@ -393,3 +396,8 @@ class HeteroNNContractor(RSAContractor):
         """Finish the specified task."""
         event = CompleteTaskEvent() if is_succ else FailTaskEvent()
         self._new_contract(targets=self.EVERYONE, event=event)
+
+    def reset_round(self):
+        """Reset current training round."""
+        event = ResetRoundEvent()
+        self._new_contract(targets=self.EVERYONE, event=event)
