@@ -1,14 +1,10 @@
 import logging
 
-from concurrent_log_handler import ConcurrentRotatingFileHandler
 
 __all__ = ['logger', 'task_logger']
 
 if 'alphafed' in logging.Logger.manager.loggerDict.keys():
     logger = logging.getLogger('alphafed')
-    logfile = '/logs/alphafed.log'
-    handler = ConcurrentRotatingFileHandler(logfile, "a", 512*1024, 5)
-    logger.addHandler(handler)
 
 else:
     format = '%(asctime)s|%(levelname)s|%(module)s|%(funcName)s|%(lineno)d:\n%(message)s'
